#!/usr/bin/env python

"""
HTML serialiser.

Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.common import Serialiser



# The serialiser class.

class HTMLSerialiser(Serialiser):

    "Serialisation of HTML fragments."

    input_formats = ["html"]
    formats = ["html"]

    def attribute(self, attribute):
        self.out(attribute.name)
        if attribute.value is not None:
            self.out("=")
            self.visit(attribute.value)

    def attribute_value(self, attribute_value):
        self.out("%s%s%s" % (attribute_value.quote, attribute_value.value, attribute_value.quote))

    def element(self, element):
        self.out("<%s" % element.name)
        for attribute in element.attributes:
            self.out(" ")
            self.visit(attribute)
        self.out(">")
        self.container(element)
        self.out("</%s>" % element.name)

    def comment(self, comment):
        self.out("<%s>" % comment.value)

    def directive(self, directive):
        self.out("<%s>" % directive.value)

    def inclusion(self, inclusion):
        self.out("<%s>" % inclusion.value)

    def node(self, node):
        self.out(node.value)

    text = node

    def fragment(self, fragment):
        self.container(fragment)

serialiser = HTMLSerialiser

# vim: tabstop=4 expandtab shiftwidth=4
