#!/usr/bin/env python

"""
Prettyprinted HTML document node prettyprinter.

Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.pretty.common import Serialiser

class HTMLSerialiser(Serialiser):

    "Serialisation of prettyprinted document nodes for inspection."

    input_formats = ["html"]
    formats = ["pretty"]

    def attribute(self, attribute):
        self.out("%sAttribute: %s" % (self.output.indent, attribute.name))
        if attribute.value is not None:
            self.out("=")
        self.visit(attribute.value)
        self.out("\n")

    def attribute_value(self, attribute_value):
        self.out("%s%s%s" % (attribute_value.quote, attribute_value.value, attribute_value.quote))

    def element(self, element):
        self.out("%sElement: name=%r\n" % (self.output.indent, element.name))
        self.output.indent += "  "
        for attribute in element.attributes:
            self.visit(attribute)
        self.output.indent = self.output.indent[:-2]
        self.container(element)

    def node(self, node):
        self.out("%s%s: %r\n" % (self.output.indent, node.__class__.__name__, node.value))

    comment = node
    directive = node
    inclusion = node
    text = node

    def fragment(self, fragment):
        self.out("%s%s\n" % (self.output.indent, fragment.__class__.__name__))
        self.container(fragment)

serialiser = HTMLSerialiser

# vim: tabstop=4 expandtab shiftwidth=4
