#!/usr/bin/env python

"""
HTML document nodes.

Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

# Element attributes.

class Attribute:
    def __init__(self, name, value=None):
        self.name = name
        self.value = value

    def __repr__(self):
        return "%s(%r, %r)" % (self.__class__.__name__, self.name, self.value)

    def visit(self, visitor):
        visitor.attribute(self)



# Nodes containing other nodes.

class Fragment:
    def __init__(self, nodes=None):
        self.nodes = nodes or []

    def __repr__(self):
        return "%s(%r)" % (self.__class__.__name__, self.nodes)

    def visit(self, visitor):
        visitor.fragment(self)

class Element(Fragment):
    def __init__(self, name, attributes=None, nodes=None):
        Fragment.__init__(self, nodes)
        self.name = name
        self.attributes = attributes or []

    def __repr__(self):
        return "%s(%r, %r, %r)" % (self.__class__.__name__, self.name, self.attributes, self.nodes)

    def visit(self, visitor):
        visitor.element(self)



# Nodes having values.

class Node:
    def __init__(self, value):
        self.value = value

    def __repr__(self):
        return "%s(%r)" % (self.__class__.__name__, self.value)

    def visit(self, visitor):
        visitor.node(self)

class AttributeValue(Node):
    def __init__(self, value, quote):
        Node.__init__(self, value)
        self.quote = quote

    def __repr__(self):
        return "%s(%r, %r)" % (self.__class__.__name__, self.value, self.quote)

    def visit(self, visitor):
        visitor.attribute_value(self)

class Comment(Node):
    def visit(self, visitor):
        visitor.comment(self)

class Directive(Node):
    def visit(self, visitor):
        visitor.directive(self)

class Inclusion(Node):
    def visit(self, visitor):
        visitor.inclusion(self)

class Text(Node):
    def visit(self, visitor):
        visitor.text(self)

# vim: tabstop=4 expandtab shiftwidth=4
